Toolbar
Date: 08 20, 2001 1:58:48 PM

# Toolbars

The toolbars on the VisualText™ interface provide quick and easy access to the most commonly used commands. You can move the toolbars to any location on the interface. You can also open and close any combination of them to suit your needs.

To move a toolbar, left click on the two bars on the left edge of the toolbar and drag it to the desired location. You can also move the toolbar by putting the pointer on the edge of the toolbar in an area that doesn't display a button or pulldown menu.

When a toolbar is selected it will appear indented.

To see a description of each of these toolbars, click on the toolbar titles below.

## Main Toolbar

## Tab Toolbar

## Browser Toolbar

## Workspace Toolbar

## Debug Toolbar